#ifndef MSOCKETSNOTIFIER_H_
#define MSOCKETSNOTIFIER_H_

/**
 * This class should be used by the sockets engine to inform
 * any listener about events.
 * These include information messages (errors or infos like
 * a successful connection) and messages that are received through
 * a socket connection.
 */
class MSocketsNotifier
{
public:
/**
 * Inform the listener about notable events.
 * These can include information about the general process
 * (aError == KErrNone) or errors. The message can contain
 * additional information about what happened.
 * 
 * @param aError error code, KErrNone (0) if it's an information
 * message.
 * @param aMsg message text.
 */
virtual void NotifyInfo(TInt aError, const TDesC& aMsg) = 0;

/**
 * Whenever the sockets reader receives data, it is sent
 * to the listener through this method.
 * 
 * @param aData 8 bit descriptor that contains the data
 * received through the socket reader.
 */
virtual void MessageReceived(const TDesC8& aData) = 0;
};

#endif /*MSOCKETSNOTIFIER_H_*/
