/*
============================================================================
 Name		 : SocketsReader.h
 Copyright   : Symbian Academy, 2007
 Description : Waits for data from the connected socket and informs a 
               listener via a callback whenever data is received.
============================================================================
*/

#ifndef SOCKETSREADER_H
#define SOCKETSREADER_H

#include <e32base.h>	// For CActive, link against: euser.lib
#include <e32std.h>

#include <es_sock.h>
#include "MSocketsNotifier.h"

#define KMAXLENGTH	100

class CSocketsReader : public CActive
{
public:
	// Cancel and destroy
	~CSocketsReader();

	// Two-phased constructor.
	static CSocketsReader* NewL(RSocket* aSocket, MSocketsNotifier* aNotifier);

	// Two-phased constructor.
	static CSocketsReader* NewLC(RSocket* aSocket, MSocketsNotifier* aNotifier);

public: // New functions
	// Function for making the initial request
	void IssueReadL(  );

private:
	// C++ constructor
	CSocketsReader(RSocket* aSocket, MSocketsNotifier* aNotifier);
	
	// Second-phase constructor
	void ConstructL();
	
private: // From CActive
	// Handle completion
	void RunL();
	
	// How to cancel me
	void DoCancel();
	
private:
	enum TSocketsReaderState
	{
		EUninitialized,	// Uninitialized
		EInitialized,	// Initalized
		EError			// Error condition
	};

private:
	TInt	iState;		// State of the active object

	/**
	 * A socket that can be used to read data.
	 * Connecting and disconnecting is not performed by this class.
	 */
	RSocket* iSocket;				// owned by AppUi
	
	// Edit 28: Define an 8 bit stack-based descriptor buffer called iBuffer,
	//          which should have the maximum length defined by KMAXLENGTH
	//          directly above this class definition
	
	
	// Edit 29: Reading from sockets will return the length of the data that
	//          was read. To store it, define a variable of type TSockXfrLength.

	
	/**
	 * For notifying a listener when a message is received.
	 */
	MSocketsNotifier* iNotifier;	// owned by AppUi
};

#endif // SOCKETSREADER_H
